/////////////////////////////////////////////////
// Appendix Table A1
/////////////////////////////////////////////////

use appendixdata.dta, clear

* And then keep one observation per AEA
keep if tag_aea==1

gen treat1 = .
gen treat2 = .


***************************** Large ALATs *********************************

replace treat1 = treat100_large
replace treat2 = treat50_large

local treatvars 1.treat1 1.treat2
local controls 1.AEA_male c.AEA_age 1.AEA_Colorado

* Column 1
eststo col1: reg nonmissing `treatvars' if large==1 & CARGO3=="Tecnico", cluster(ALAT)
	testparm `treatvars'
	estadd scalar pval r(p)


* Column 2
eststo col2: reg nonmissing (`controls')##(`treatvars') ///
  if large==1 & CARGO3=="Tecnico", cluster(ALAT)

	testparm `treatvars' (`controls')#(`treatvars')
	estadd scalar pval r(p)
	estadd local ctrl1 "$\checkmark$"
	

***************************** Small ALATs *********************************

replace treat1 = treatw1_small
replace treat2 = treatw2_small

* Column 3
eststo col3: reg nonmissing `treatvars' ///
  if large==0 & CARGO3=="Tecnico", cluster(ALAT)
	
	testparm `treatvars'
	estadd scalar pval r(p)

* Column 4
eststo col4: reg nonmissing (`controls')##(`treatvars') ///
  if large==0 & CARGO3=="Tecnico", cluster(ALAT)
	
	testparm `treatvars' (`controls')#(`treatvars')
	estadd scalar pval r(p)
	estadd local ctrl1 "$\checkmark$"
	
	
************************** Conditional on employment***********************


***************************** Large ALATs *********************************

replace treat1 = treat100_large
replace treat2 = treat50_large

local treatvars 1.treat1 1.treat2
local controls 1.AEA_male c.AEA_age 1.AEA_Colorado ///
               1.married c.digit_span_orig c.big5_stability_orig c.big5_plasticity_orig

* Column 5
eststo col5: reg nonmissing_cond `treatvars' ///
  if large==1 & CARGO3=="Tecnico", cluster(ALAT)
	
	testparm `treatvars'
	estadd scalar pval r(p)

* Column 6
eststo col6: reg nonmissing_cond (`controls')##(`treatvars') ///
  if large==1 & CARGO3=="Tecnico", cluster(ALAT)

	testparm `treatvars' (`controls')#(`treatvars')
	estadd scalar pval r(p)
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	

***************************** Small ALATs *********************************

replace treat1 = treatw1_small
replace treat2 = treatw2_small

* Column 7
eststo col7: reg nonmissing_cond `treatvars' ///
  if large==0 & CARGO3=="Tecnico", cluster(ALAT)
	
	testparm `treatvars'
	estadd scalar pval r(p)

* Column 8
eststo col8: reg nonmissing_cond (`controls')##(`treatvars') ///
  if large==0 & CARGO3=="Tecnico", cluster(ALAT)

	testparm `treatvars' (`controls')#(`treatvars')
	estadd scalar pval r(p)
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	

#delimit;
esttab col*
  using "tablea1.tex",
  booktabs type replace
  b(a2)
	se(a2)
  label
	coeflabels(1.treat1 "Treat 1"
	           1.treat2 "Treat 2"
						 1.AEA_male#1.treat1 "Male \$\times\$ Treat 1"
						 1.AEA_male#1.treat2 "Male \$\times\$ Treat 2"
						 1.treat1#c.AEA_age "Age \$\times\$ Treat 1"
						 1.treat2#c.AEA_age "Age \$\times\$ Treat 2"
						 1.AEA_Colorado#1.treat1 "Incumbent Party \$\times\$ Treat 1"
						 1.AEA_Colorado#1.treat2 "Incumbent Party \$\times\$ Treat 2"
						 1.married_orig#1.treat1 "Married \$\times\$ Treat 1"
						 1.married_orig#1.treat2 "Married \$\times\$ Treat 2"
						 1.treat1#c.digit_span_orig "Digit Span \$\times\$ Treat 1"
						 1.treat2#c.digit_span_orig "Digit Span \$\times\$ Treat 2"
						 1.treat1#c.big5_stability_orig "Big 5 Stability \$\times\$ Treat 1"
						 1.treat2#c.big5_stability_orig "Big 5 Stability \$\times\$ Treat 2"
						 1.treat1#c.big5_plasticity_orig "Big 5 Plasticity \$\times\$ Treat 1"
						 1.treat2#c.big5_plasticity_orig "Big 5 Plasticity \$\times\$ Treat 2")
	keep(*1.treat*)
	scalars("ctrl1 Basic Controls"
		  		"ctrl2 Cognitive Controls"
					"pval \$p\$-value of \$F\$-test"
					"N     N")
	sfmt("%50s" "%50s" "a2" "%50s")
	noobs
	nomtitles
	compress
	prehead("{
\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
    \begin{tabular}{lcccccccc}
    \toprule
          & \multicolumn{4}{c}{Non-missing} & \multicolumn{4}{c}{Non-missing, conditional on employment} \\
            \cmidrule(lr){2-5} \cmidrule(lr){6-9}
          & \multicolumn{2}{c}{Large ALATs} & \multicolumn{2}{c}{Small ALATs} & \multicolumn{2}{c}{Large ALATs} & \multicolumn{2}{c}{Small ALATs} \\");
#delimit cr

/////////////////////////////////////////////////
// Appendix Table A2
/////////////////////////////////////////////////

use appendixdata.dta, clear

* Limit it to the relevant sample.
keep if missing_notemployed==0 & missing_variables==0


***************************** Large *********************************

matrix means = J(1, 2, .)
matrix colnames means = model1 model2

matrix obs   = means
matrix coef1  = means
matrix coef2  = means
matrix se1    = means
matrix se2    = means


** Phone Numbers
* Means
sum PhoneNumber if treat_alat==1 & CARGO=="Tecnico" & tag_aea==1
  matrix means[1, 1] = r(mean)

* Everything else
reg PhoneNumber treat100_large treat50_large if treat_alat!=. & CARGO=="Tecnico" & tag_aea==1, cluster(ALAT)
  matrix obs[1, 1]   = e(N)
	matrix coef1[1, 1] = _b[treat100_large]
	matrix se1[1, 1]   = _se[treat100_large]
	matrix coef2[1, 1] = _b[treat50_large]
	matrix se2[1, 1]   = _se[treat50_large]
	
** Phone in Final Sample
* Means
sum complete_our if treat_alat==1 & CARGO=="Tecnico"
  matrix means[1, 2] = r(mean)

* Everything else
reg complete_our treat100_large treat50_large if treat_alat!=. & CARGO=="Tecnico", cluster(ALAT)
  matrix obs[1, 2]   = e(N)
	matrix coef1[1, 2] = _b[treat100_large]
	matrix se1[1, 2]   = _se[treat100_large]
	matrix coef2[1, 2] = _b[treat50_large]
	matrix se2[1, 2]   = _se[treat50_large]
	
** Post
ereturn post obs
eststo obs_large

ereturn post means
eststo means_large

ereturn post coef1
estadd matrix se = se1
eststo coef1_large

ereturn post coef2
estadd matrix se = se2
eststo coef2_large



***************************** Small *********************************

matrix means = J(1, 2, .)
matrix colnames means = model1 model2

matrix obs   = means
matrix coef1  = means
matrix coef2  = means
matrix se1    = means
matrix se2    = means


** Phone Numbers
* Means
sum PhoneNumber if treat_ind==1 & CARGO=="Tecnico" & tag_aea==1
  matrix means[1, 1] = r(mean)

* Everything else
reg PhoneNumber treatw1_small treatw2_small if treat_ind!=. & CARGO=="Tecnico" & tag_aea==1, cluster(ALAT)
  matrix obs[1, 1]   = e(N)
	matrix coef1[1, 1] = _b[treatw1_small]
	matrix se1[1, 1]   = _se[treatw1_small]
	matrix coef2[1, 1] = _b[treatw2_small]
	matrix se2[1, 1]   = _se[treatw2_small]
	
** Phone in Final Sample
* Means
sum complete_our if treat_ind==1 & CARGO=="Tecnico"
  matrix means[1, 2] = r(mean)

* Everything else
reg complete_our treatw1_small treatw2_small if treat_ind!=. & CARGO=="Tecnico", cluster(ALAT)
  matrix obs[1, 2]   = e(N)
	matrix coef1[1, 2] = _b[treatw1_small]
	matrix se1[1, 2]   = _se[treatw1_small]
	matrix coef2[1, 2] = _b[treatw2_small]
	matrix se2[1, 2]   = _se[treatw2_small]

	** Post
ereturn post obs
eststo obs_small

ereturn post means
eststo means_small

ereturn post coef1
estadd matrix se = se1
eststo coef1_small

ereturn post coef2
estadd matrix se = se2
eststo coef2_small


#delimit;
esttab obs_large means_large coef1_large coef2_large
       obs_small means_small coef1_small coef2_small
  using "tablea2.tex",
  booktabs type replace
	b(a2)
	se(a2)
	nostar
  refcat(model1 "\textbf{Panel A}:"
	       model2 "\textbf{Panel B}:", nolabel)	
	coeflabels(model1 "Phone numbers per AEA"
	           model2 "Phone number in final sample")
	noobs
	nonumbers
	nonotes
	compress
	prehead("\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
\begin{tabular}{lcccccccc}
    \toprule
          & \multicolumn{4}{c}{Large ALATs} & \multicolumn{4}{c}{Small ALATs} \\
          \cmidrule(lr){2-5} \cmidrule(lr){6-9}
          	&	 N 	&	 Ctrl 	&	 T100-Ctrl 	&	 T50-Ctrl 	&	 N 	&	 Ctrl 	&	 Wave 1-Ctrl 	&	 Wave 2-Ctrl 	\\
\cmidrule{2-9}          & (1)   & (2)   & (3)   & (4)   & (5)   & (6)   & (7)   & (8) \\");

#delimit cr


