clear all
set matsize 3000

quietly do functions.do

use maindata.dta, clear


/////////////////////////////////////////////////
// Table 1
/////////////////////////////////////////////////
keep if cargo=="Tecnico" & tag_aea==1

#delimit;
local covlist AEA_male
							AEA_age
							married
							dist_mean
							AEA_Colorado
							digit_span
							big5_stability
							big5_plasticity;
#delimit cr

* make it so 0 is control, and 1 is column 1 and 2 is column 2 for the table
recode treat_ind (1=0) (2=2) (3=1), gen(col_small)
recode treat_alat (1=0) (2=2) (3=1), gen(col_big)

eststo balance_big: balance `covlist', treat(col_big) cluster(ALAT_deag)
eststo balance_small: balance `covlist', treat(col_small) cluster(ALAT_deag)

#delimit;
esttab balance_big balance_small
		using "table1.tex",
		booktabs replace type
		cell(`"mean(fmt(a2)) b1(fmt(a2)) b2(fmt(a2))"'
				 "sd(fmt(a2) par([ ])) se1(fmt(a2) par(( ))) se2(fmt(a2) par(( )))")
		nostar
		extracols(4)
		order(`covlist')
		coeflabels(AEA_male "Male"
							 AEA_age "Age"
							 married "Married"
							 dist_mean "Average Distance"
							 AEA_Colorado "Incumbent Party"
							 digit_span "Digit Span"
							 big5_stability "Big 5 --- Stability"
							 big5_plasticity "Big 5 --- Plasticity")
		stats(aea0 aea1 aea2 alat0 alat1 alat2,
					fmt(0 0 0 0 0 0)
					layout("@ @ @" "@ @ @")
					labels("Num AEAs" "Num ALATs"))
		mlabels("Large ALATs" "Small ALATs",
						span
						prefix(\multicolumn{@span}{c}{) suffix(})
						erepeat(\cmidrule(lr){@span}))
		nonumbers
		collabels(none)
		prehead("\begin{tabular}{lccccccc} \toprule") 
		posthead("&        Ctrl&\shortstack{Diff\\(T100-C)}   &\shortstack{Diff\\(T50-C)}   &            &        Ctrl&\shortstack{Diff\\(Wave 1-C)}   &\shortstack{Diff\\(Wave 2-C)}   \\"
						 "\midrule");
#delimit cr


//////////////////////////////////////////////////////////////////////////
//Table 2
//////////////////////////////////////////////////////////////////////////
use maindata.dta, clear

replace treat = phone4
local cond cargo=="Tecnico" & treat_alat != 2
local cond_nosmall `cond' & small==0
local cond_jefe cargo=="Jefe Tecnico" & treat_alat != 2
local cond_aea cargo=="Tecnico" & treat_alat != 2 & tag_aea==1

local ctrl_aea1 AEA_age married ldist_mean AEA_male AEA_Colorado
local ctrl_aea2 `ctrl_aea1' big5_stability big5_plasticity digit_span

eststo visit_noctrl: ///
	reg dvisit_week treat select 2.fps_round small ///
	  if `cond', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 ""
	estadd local ctrl2 ""
	mainfx_sumstats

eststo visit_ctrl1: ///
	reg dvisit_week treat select 2.fps_round small `ctrl_aea1' ///
		if `cond', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 ""
	mainfx_sumstats

eststo visit_ctrl2: ///
	reg dvisit_week treat select 2.fps_round small `ctrl_aea2' ///
		if `cond', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

eststo visit_ctrl2_nosmall: ///
	reg dvisit_week treat select 2.fps_round small `ctrl_aea2' ///
		if `cond_nosmall', cluster(ALAT_deag)

	estadd local small ""
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

eststo visit_ctrl2_jefe: ///
	reg dvisit_week treat 2.fps_round small `ctrl_aea2' ///
		if `cond_jefe', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "Supervisor"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

replace treat = phone3
eststo know_ctrl2: ///
	reg o1_boss_knows treat select small `ctrl_aea2' ///
		if `cond_aea', cluster(ALAT_deag)
		
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	estadd local N "", replace
	mainfx_sumstats

replace treat = phone4
eststo length_ctrl2: ///
	reg ln_last_meeting_minutes treat select 2.fps_round small `ctrl_aea2' ///
		if `cond', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

* Polychoric PCA command does not admit if statements
preserve
keep if `cond'

polychoricpca satisfaction training useful, score(pca) nscore(1)


eststo pca1_ctrl2: ///
	reg pca1 treat select 2.fps_round small `ctrl_aea2', cluster(ALAT_deag)
	
	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

restore


#delimit;
esttab visit_noctrl visit_ctrl1 visit_ctrl2 visit_ctrl2_nosmall
			 visit_ctrl2_jefe know_ctrl2 length_ctrl2 pca1_ctrl2
  using "table2.tex",
	booktabs
	replace
	type
	b(a2)
	se(a2)
	nostar
	keep(treat select)
	order(treat select)
	noobs
	coeflabels(treat "\textbf{Treated}"
						 select "\emph{Selected}")
	mgroups("Farmer was visited in the last week"
					"\shortstack{Supervisor\\knows}"
					"\shortstack{Log length of\\meeting (mins)}"
					"PCA",
		pattern(1 0 0 0 0 1 1 1)
		span
		prefix(\multicolumn{@span}{c}{)
		suffix(})
		erepeat(\cmidrule(lr){@span}))
	scalars("type Servicer"
					"y_notreat Mean of Control Dep. Var"
					"r2 \$R^2\$"
					"N Number of Phone Surveys"
					"N_AEA Number of AEAs"
					"N_clust Number of ALATs"
					"small Includes Small ALATs"
					"ctrl1 Basic Controls"
					"ctrl2 Cognitive Controls")
	sfmt("%50s" "a2")
	nomtitles
	eqlabels(off)
	collabels(none)
	nonotes;
#delimit cr


///////////////////////////////////////////////////
//Table 4
///////////////////////////////////////////////////
local cond cargo=="Tecnico" & treat_alat != 2
local cond_spill cargo=="Tecnico" & small==0
local cond_aea cargo=="Tecnico" & treat_alat != 2 & tag_aea==1

local ctrl_aea1 AEA_age married ldist_mean AEA_male AEA_Colorado
local ctrl_aea2 `ctrl_aea1' big5_stability big5_plasticity digit_span


eststo visit_hawthorne2: ///
	reg dvisit_week treat select 1.treat#1.small 2.fps_round small `ctrl_aea2' ///
		if `cond', cluster(ALAT_deag)

	estadd local small "$\checkmark$"
	estadd local type "AEA"
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	estadd local phones = e(N)
	mainfx_sumstats

eststo visit_jefe_spill: ///
	reg dvisit_week treat select 1.treat#1.select 2.fps_round `ctrl_aea2' E1 F1 ///
			if `cond_spill', cluster(ALAT_deag)

	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	estadd local phones = e(N)
	estadd local alat50 "$\checkmark$"
	mainfx_sumstats

* For AEA survey effects, need to define treatment as only those who had the
* phone in wave 1
replace treat = phone3
eststo boss_call: ///
	reg boss_call treat select 1.treat#1.select small `ctrl_aea2' if `cond_aea', cluster(ALAT_deag)
		estadd local small "$\checkmark$"
		estadd local type "AEA"
		estadd local ctrl1 "$\checkmark$"
		estadd local ctrl2 "$\checkmark$"
		mainfx_sumstats

eststo boss_see: ///
	reg boss_see treat select 1.treat#1.select small `ctrl_aea2' if `cond_aea', cluster(ALAT_deag)
		estadd local small "$\checkmark$"
		estadd local type "AEA"
		estadd local ctrl1 "$\checkmark$"
		estadd local ctrl2 "$\checkmark$"
		mainfx_sumstats
		
#delimit;
esttab visit_jefe_spill visit_hawthorne2 boss_call boss_see
	using "table4.tex", 
	type replace booktabs 
	b(a2)
	se(a2)
	nostar
	keep(small select treat 1.treat#1.small 1.treat#1.select F1 E1)
	order(treat 1.treat#1.select 1.treat#1.small F1 E1 select small)
	noobs
	scalars("y_notreat Mean of Control Dep. Var"
					"r2 \$R^2\$"
					"phones Number of Phone Surveys"
					"N_AEA Number of AEAs"
					"N_clust Number of ALATs"
					"small Includes Small ALATs"
					"alat50 Includes Includes 50\% Treatment ALATs"
					"ctrl2 Includes Basic and Cognitive Controls")
	sfmt("a2" "a2" "%4.0f" "%4.0f" "%4.0f")
	mgroups("Farmer visited"
					"\shortstack{Supervisor\\called}"
					"\shortstack{Supervisor\\met}",
		pattern(1 0 1 1)
		span
		prefix(\multicolumn{@span}{c}{)
		suffix(})
		erepeat(\cmidrule(lr){@span}))
	nomtitles
	eqlabels(off)
	collabels(none)
	coeflabels(small "Small"
						 select "\emph{Selected}"
						 treat "\textbf{Treated}"
						 1.treat#1.small "\textbf{Treated} $\times$ Small"
						 1.treat#1.select "\textbf{Treated} $\times$ \emph{Selected}"
						 F1 "F1"
						 E1 "E1")
	nonotes
	prehead("{\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}\begin{tabularx}{0.6\textwidth}{l*{4}{Z}}\toprule")
	postfoot("\end{tabularx}}");
#delimit cr
		
		
///////////////////////////////////////////////////
//Table 3
///////////////////////////////////////////////////

* From here on out, use sample on Tecnicos and large ALATs
* Also limit sample to those who are not missing selected
* keep large ALATs
drop if missing(treat_alat)
keep if cargo=="Tecnico"
keep if treat_alat != 2

* some of the tagged observations are getting dropped when we limit the sample
drop tag_aea
egen tag_aea = tag(CICN)

local ctrl_aea1 AEA_age married ldist_mean AEA_male AEA_Colorado
local ctrl_aea2 `ctrl_aea1' big5_stability big5_plasticity digit_span


** Treatment effect interaction
** Do one of these on the main sample and one of these on the full sample
replace treat = phone4

eststo visit_jefe_noctrl: ///
	reg dvisit_week treat select 1.treat#1.select 2.fps_round, cluster(ALAT_deag)
	
	estadd local ctrl1 ""
	estadd local ctrl2 ""
	mainfx_sumstats

	
eststo visit_jefe_ctrl2: ///
	reg dvisit_week treat select 1.treat#1.select 2.fps_round `ctrl_aea2', cluster(ALAT_deag)
	
	estadd local ctrl1 "$\checkmark$"
	estadd local ctrl2 "$\checkmark$"
	mainfx_sumstats

	
#delimit;
esttab visit_jefe_noctrl visit_jefe_ctrl2
	using "table3.tex", 
	type replace booktabs
	b(a2)
	se(a2)
	nostar
	keep(select treat 1.treat#1.select)
	order(treat 1.treat#1.select select)
	noobs
	scalars("y_notreat Mean of Control Dep. Var"
					"r2 \$R^2\$"
					"N Number of Phone Surveys"
					"N_AEA Number of AEAs"
					"N_clust Number of ALATs"
					"ctrl1 Includes Basic Controls"
					"ctrl2 Includes Cognitive Controls")
	sfmt("a2" "a2" "%4.0f" "%4.0f" "%4.0f" )
	mgroups("Farmer visited",
		pattern(1 0)
		span
		prefix(\multicolumn{@span}{c}{)
		suffix(})
		erepeat(\cmidrule(lr){@span}))
	nomtitles
	eqlabels(off)
	collabels(none) 
	coeflabels(select "\emph{Selected}"
						 treat "\textbf{Treated}"
						 1.treat#1.select "\textbf{Treated} $\times$ \emph{Selected}")
	nonotes ;
#delimit cr
	



///////////////////////////////////////////////////
//Table 5
///////////////////////////////////////////////////
* impose that on average, the main effect on treatment reflects the ATE
foreach var of varlist AEA_age married digit_span ldist_mean ///
											 big5_stability big5_plasticity AEA_male AEA_Colorado {
	sum `var' 
	replace `var' = (`var' - r(mean))
}


** First stage
local ctrl_aea1 c.AEA_age c.married c.ldist_mean c.AEA_male c.AEA_Colorado
local ctrl_aea2 `ctrl_aea1' c.big5_stability c.big5_plasticity c.digit_span

eststo probit_noctrl: probit select if tag_aea==1, cluster(ALAT_deag)

eststo probit_ctrl1:  probit select `ctrl_aea1' if tag_aea==1, cluster(ALAT_deag)
estadd local ctrl1 "$\checkmark$"

eststo probit_ctrl2:  probit select `ctrl_aea2' if tag_aea==1, cluster(ALAT_deag)
estadd local ctrl1 "$\checkmark$"
estadd local ctrl2 "$\checkmark$"


#delimit;
esttab probit_ctrl1 probit_ctrl2
  using "table5a.tex",
	type replace booktabs
	b(a2)
	se(a2)
	nostar
	unstack
	nomtitles
	nodepvars
	eqlabels(none)
	collabels(none)
	equations(1)
	drop(_cons)
	order(AEA_male AEA_age married ldist_mean AEA_Colorado digit_span big5_stability ///
				big5_plasticity) ///
	coeflabels(AEA_male "Male"
						 AEA_age "Age"
						 married "Married"
						 ldist_mean "Average Distance"
						 AEA_Colorado "Incumbent Party"
						 digit_span "Digit Span"
						 big5_stability "Big 5 --- Stability"
						 big5_plasticity "Big 5 --- Plasticity")
	noobs
	mgroups("AEA was selected",
		pattern(1 0)
		span
		prefix(\multicolumn{@span}{c}{)
		suffix(})
		erepeat(\cmidrule(lr){@span}))
	scalars("r2_p Pseudo \$R^2\$"
					"N Number of AEAs"
					"N_clust Number of ALATs")
	sfmt("a2" "%4.0f" "%4.0f")
	nonotes;
#delimit cr

olsliml, techctrls(2.fps_round) name(ols_noctrl)
olsliml `ctrl_aea1', techctrls(2.fps_round) name(ols_ctrl1)
estadd local ctrl1 "$\checkmark$": ols_ctrl1

olsliml `ctrl_aea2', techctrls(2.fps_round) name(ols_ctrl2)
estadd local ctrl1 "$\checkmark$": ols_ctrl2
estadd local ctrl2 "$\checkmark$": ols_ctrl2


#delimit;
esttab ols_noctrl ols_ctrl1 ols_ctrl2
  using "table5b.tex",
	type replace booktabs
	b(a2)
	se(a2)
	nostar
	nomtitles
	collabels(none)
	eqlabels(off)
	keep(1.treat* gresid )
	order(gresid 1.treat 1.treat#c.gresid 1.treat#c.AEA_male 1.treat#c.AEA_age
				1.treat#c.married 1.treat#c.ldist_mean 1.treat#c.AEA_Colorado 1.treat#c.digit_span
				1.treat#c.big5_stability 1.treat#c.big5_plasticity)
	coeflabels(gresid "\emph{Inverse Mills Ratio}"
						 1.treat "\textbf{Average Treatment Effect}" 
						 1.treat#c.gresid "\emph{Inverse Mills}"
						 1.treat#c.AEA_age "Age"
						 1.treat#c.AEA_male "Male"
						 1.treat#c.married "Married"
						 1.treat#c.ldist_mean "Average Distance to Farmers (log)"
						 1.treat#c.AEA_Colorado "Incumbent Party"
						 1.treat#c.digit_span "Digit Span"
						 1.treat#c.big5_stability "Big5 -- Stability"
						 1.treat#c.big5_plasticity "Big5 --- Plasticity")
	interaction("\times")
	refcat(gresid "Main Effects:"
				 1.treat#c.gresid "\textbf{Interactions with Treatment:}", nolabel)
	noobs
	scalars("r2 \$R^2\$"
					"jointp_conv \$p\$-value for Observable Interactions"
					"N Number of Phone Surveys"
					"N_AEA Number of AEAs"
					"N_clust Number of ALATs"
					"ctrl1 Basic Controls"
					"ctrl2 Cognitive Controls")
	sfmt("a2" "a2" "%4.0f" "%4.0f" "%4.0f")
	mgroups("Farmer was visited in the last week",
		pattern(1 0 0)
		span
		prefix(\multicolumn{@span}{c}{)
		suffix(})
		erepeat(\cmidrule(lr){@span}))
	nonotes;
#delimit cr

///////////////////////////////////////////////////
//Figure 3
///////////////////////////////////////////////////
local ctrl_aea1 AEA_age married ldist_mean AEA_male AEA_Colorado
local ctrl_aea2 `ctrl_aea1' big5_stability big5_plasticity digit_span

eststo pred_ctrl: reg dvisit_week `ctrl_aea2' 2.fps_round if treat==0

* Predict negative distance just so I can stick it into the algorithm
gen neg_ldist_mean = -ldist_mean
eststo pred_dist: reg neg_ldist_mean ldist_mean


local regressors $ctrl2_nofv

* Goal is to obtain tau hats from fully interacted regression
local Wset `ctrl_aea2' treat 2.fps_round

* Create interactions
foreach regressor in `ctrl_aea2' {
	gen `regressor'_treat = treat*`regressor'
}

* Residualize LHS
reg dvisit_week `Wset'
predict resid, resid
replace resid = resid*-1

* Residualize Interactions
foreach regressor in `ctrl_aea2' {
	reg `regressor'_treat `Wset'
	predict `regressor'_treatresid, resid
}

* Rename Interactions as main effects for figure program
foreach regressor in `ctrl_aea2' {
	gen `regressor'_original = `regressor'
	replace `regressor' = `regressor'_treatresid
}

eststo pred_soph: reg resid `ctrl_aea2'

* Put the original variables back into place
foreach regressor in `ctrl_aea2' {
	replace `regressor' = `regressor'_original
}


gen ONE = 1


* Collapse all the data to the AEA level. At this point
* all I need to do is make predictions
collapse (first) AEA_age married digit_span ldist_mean big5_stability ///
								 big5_plasticity AEA_male AEA_Colorado ///
								 fps_round select treat ///
								 dvisit_week_mean ALAT_deag ///
		     (count) weight=ONE, by(CICN)


gen gresid = 0
replace fps_round = 0
//gen tau = 0
//gen postau = 0
//gen pscore = .

quietly sum weight
replace weight = weight/r(sum)


* Specify which specification the treatment effects come from
local effect_spec ctrl2

** Generate the matrices
rainbow_prob, outputmatrix(pred_sup)
rainbow_pred, outputmatrix(pred_ctrl) pred_spec(pred_ctrl)
rainbow_pred, outputmatrix(pred_dist) pred_spec(pred_dist)
rainbow_pred, outputmatrix(pred_soph) pred_spec(pred_soph)

local ate = pred_sup[500,3]

* Linearly interpolate all the predictions to graph because there's
* different number of points of prediction
process_mat, mat(pred_sup) columns(3 4) ate(`ate')
process_mat, mat(pred_ctrl) columns(3) ate(`ate')
process_mat, mat(pred_dist) columns(3) ate(`ate')
process_mat, mat(pred_soph) columns(3) ate(`ate')

svmat pred_sup
svmat pred_ctrl
svmat pred_dist
svmat pred_soph

* Rename these things and reorganize for graphing
rename pred_sup1 x
rename pred_sup2 pred_sup_nounobs
rename pred_sup3 pred_sup_supunobs

rename pred_ctrl2 pred_ctrl
rename pred_dist2 pred_dist

rename pred_soph2 pred_soph

#delimit;
graph twoway ///
  (function y = `ate'*x, lcolor(black) lpattern(dot) lwidth(medthick))
  (line pred_sup_nounobs x, lcolor(gs10) lpattern(dash_dot))
  (line pred_sup_supunobs x, lcolor(gs10) lpattern(solid) lwidth(medthick)),
	
  graphregion(color(white) lcolor(white))
  xtitle("Fraction with cell phone")
  ytitle("Y{superscript:CF}")
  yscale(range(0 0.12))
  xlabel(0(0.2)1)
  ylabel(0(0.02)0.12)
  legend(order(1 2 3)
     label(3 "Supervisor Preference")
     label(2 "Supervisor Preference (w/o Unobservables)")
     label(1 "Random Assignment")
     cols(1)
     colfirst
     justification(left)
		 width(100));
graph export "figure3a.eps", replace;


graph twoway ///
  (function y = `ate'*x, lcolor(black) lpattern(dot) lwidth(medthick))
  (line pred_sup_supunobs x, lcolor(gs10) lpattern(solid) lwidth(medthick))
  (line pred_dist x, lcolor(gs12) lpattern(longdash))
  (line pred_ctrl x, lcolor(gs12) lpattern(shortdash))
  (line pred_soph x, lcolor(black) lpattern(dash) lwidth(medthick)),
	
  graphregion(color(white) lcolor(white))
  xtitle("Fraction with cell phone")
  ytitle("Y{superscript:CF}")
  yscale(range(0 0.12))
  xlabel(0(0.2)1)
  ylabel(0(0.02)0.12)
  legend(order(1 2 3 4 5)
     label(2 "Supervisor Preference")
     label(5 "Sophisticated Prediction")
     label(4 "Prediction (Basic and Cognitive Controls)")
     label(3 "Prioritize by Distance")
     label(1 "Random Assignment")
     cols(1)
     colfirst
     justification(left)
     width(100));
graph export "figure3b.eps", replace;
