capture program drop balance
program define balance, eclass
  syntax varlist, treat(varname) cluster(passthru)

  quietly {
    local numvars: word count `varlist'
		
    matrix b1 = J(1, `numvars', .)
    matrix colnames b1 = `varlist'

    matrix b2 = b1
    matrix se1 = b1
    matrix se2 = b1
    matrix p1 = b1
    matrix p2 = b1

		matrix mean = b1
		matrix sd = b1
		
    local counter = 1
    foreach var of varlist `varlist' {
			quietly sum `var' if `treat'==0
			matrix mean[1, `counter'] = r(mean)
			matrix sd[1, `counter'] = r(sd)
		
      reg `var' i.`treat', `cluster'

      matrix b1[1, `counter'] = _b[1.`treat']
      matrix se1[1, `counter'] = _se[1.`treat']
      matrix p1[1, `counter'] = 2*ttail(e(df_r), abs(_b[1.`treat']/_se[1.`treat']))
      matrix b2[1, `counter'] = _b[2.`treat']
      matrix se2[1, `counter'] = _se[2.`treat']
      matrix p2[1, `counter'] = 2*ttail(e(df_r), abs(_b[2.`treat']/_se[2.`treat']))


      local ++counter
    }

		quietly count if e(sample) & `treat'==0
		local aea0 = r(N)
		quietly count if e(sample) & `treat'==1
		local aea1 = r(N)
		quietly count if e(sample) & `treat'==2
		local aea2 = r(N)		


    tempvar newalat0 newalat1 newalat2

    forvalues treatstat=0/2 {
      gen `newalat`treatstat'' = ALAT_deag if `treat'==`treatstat' & e(sample)

      tempvar nunique 
      bysort `newalat`treatstat'': gen `nunique' = _n==1
      quietly count if `nunique' == 1 & !missing(`newalat`treatstat'')
      local alat`treatstat' = r(N)
      drop `nunique' `newalat`treatstat''
    }

    matrix b = [b1, b2]
    local columns
    foreach var of varlist `varlist' {
      local columns `columns' `var'_2
    }
    foreach var of varlist `varlist' {
      local columns `columns' `var'_3
    }
    matrix colnames b = `columns'

    ereturn post b

    ereturn matrix b1 b1
    ereturn matrix se1 se1
    ereturn matrix p1 p1
    ereturn matrix b2 b2
    ereturn matrix se2 se2
    ereturn matrix p2 p2
		ereturn matrix mean mean
		ereturn matrix sd sd
		
		ereturn scalar aea0 = `aea0'
		ereturn scalar aea1 = `aea1'
		ereturn scalar aea2 = `aea2'
		ereturn scalar alat0 = `alat0'
		ereturn scalar alat1 = `alat1'
		ereturn scalar alat2 = `alat2'
		
  }
end


capture program drop mainfx_sumstats
program define mainfx_sumstats
  sum `e(depvar)' if e(sample)==1 & treat==0
  estadd scalar y_notreat = r(mean)

  * the AEA tag may not be correct for the estimation sample
  tempvar tag_aea esample
  gen `esample' = e(sample)
  bys CICN `esample': gen `tag_aea' = 1 if _n==1

  count if e(sample)==1 & `tag_aea'==1
  estadd scalar N_AEA = r(N)

  drop `esample' `tag_aea'

end


capture program drop olsliml
program olsliml
  syntax [anything], name(string) [techctrls(varlist fv)]

  tempvar xb gresid

  * First stage regression
  probit select `anything' if tag_aea==1

  * Generate generalized residuals for supervisor selected
  predict `xb', xb
  replace gresid = normalden(-`xb')/(select-normal(-`xb'))

  * need this to be mean zero so everything gets loaded onto the main effect
  sum gresid
  replace gresid = gresid - r(mean)

  reg dvisit_week treat##(c.gresid `anything') `techctrls', cluster(ALAT_deag)
  eststo `name'

  * obs
  sum dvisit_week if tag_aea==1
  estadd local N_AEA = r(N): `name'

  local interactions 1.treat#c.gresid
  foreach var in `anything' {
    local interactions `interactions' 1.treat#`var'
    local constraint `constraint' 1.treat#`var'
  }

  if "`constraint'" != "" {
    test `constraint'
    estadd scalar jointp_conv = round(r(p), 0.001): `name'
  }

end



capture program drop rainbow_prob
program rainbow_prob
  syntax, outputmatrix(name)

  preserve

  tempvar xb_sup gresid_sup xb pscore tau1 tau2

  * Set up original x'*betas from supervisor probit
  estimates restore probit_ctrl2
  predict `xb_sup', xb
  gen `gresid_sup' = normalden(-`xb_sup')/(select-normal(-`xb_sup'))

  keep if !missing(`gresid_sup')

  gen `xb' = .
  gen `pscore' = .
  gen `tau1' = . // supervisor in charge without unboservables
  gen `tau2' = . // supervisor in charge with supervisor unobservables

  estimates restore ols_ctrl2
  matrix `outputmatrix' = J(500, 4, .)


  * Loop over 500 equally spaced bins of z-score thresholds from -5 to 5.
  quietly {
  forvalues i=1/500 {
  	tempvar y0 y1

    matrix `outputmatrix'[`i',1] = `i'

    replace `xb' = `xb_sup' - 5 + (`i'-1)*10/499
    replace `pscore' = normal(`xb')

    replace gresid = 0

    * New treatment effect (without any unobservables)
    replace treat = 0
    predict `y0', xb

    replace treat = 1
    predict `y1', xb

    replace `tau1' = (`y1' - `y0')*`pscore'
    drop `y0' `y1'

    tempvar y0 y1
    * New treatment effect (with supervisor unobservables)
    replace gresid = normalden(-`xb')/(1-normal(-`xb'))

    replace treat = 0
    predict `y0', xb

    replace treat = 1
    predict `y1', xb

    replace `tau2' = (`y1' - `y0')*`pscore'
    drop `y0' `y1'

    sum `pscore' [w=weight]
    matrix `outputmatrix'[`i',2] = r(mean)

    sum `tau1' [w=weight]
    matrix `outputmatrix'[`i',3] = r(mean)

    sum `tau2' [w=weight]
    matrix `outputmatrix'[`i',4] = r(mean)

  }
  }

restore

end


capture program drop rainbow_pred
program rainbow_pred
  syntax, outputmatrix(name) pred_spec(name)

  preserve

  tempvar tau cumultau xb_orig gresid_orig cumulp n
  estimates restore ols_ctrl2

  * Supervisors not involved in predictions
  replace gresid = 0

  replace treat = 0
  predict y0, xb

  replace treat = 1
  predict y1, xb

  gen `tau' = (y1 - y0)
  drop y1 y0


  ** Create the output matrix
  quietly sum `tau'
  local numobs = r(N)
  matrix `outputmatrix' = J(`numobs',3,.)


  * Sort individuals based on prediction
  estimates restore `pred_spec'
  predict `xb_orig', xb

  gsort +`xb_orig'

  * Average the taus for folks who have the same predicted index
  tempvar weighttau sumtau sumweight
  gen `weighttau' = `tau'*weight
  egen `sumtau' = sum(`weighttau'), by(`xb_orig')
  egen `sumweight' = sum(weight), by(`xb_orig')
  replace `tau' = `sumtau' / `sumweight'


  * First populate output matrix with probabilites
  gen `n' = _n
  gen `cumulp' = sum(weight)
  gen `cumultau' = sum(`tau'*weight)

  mkmat `n' `cumulp' `cumultau' if !missing(`tau'), mat(`outputmatrix')

  restore
end



* Take the rainbow data, interpolate on thousandths of a percent
* then stick it back in the matrix
capture program drop process_mat
program process_mat
  syntax, mat(name) columns(numlist) ate(real)
  preserve

  svmat `mat'

  set obs 1501

  * Generate new values to interpolate over. Do 1001 values
  replace `mat'2 = (_n-501)/1000 in 501/1501

  foreach column in `columns' {
    replace `mat'`column' = 0 in 501
    replace `mat'`column' = `ate' in 1501
    ipolate `mat'`column' `mat'2, generate(`mat'`column'_process)
  }

  mkmat `mat'2 `mat'*_process in 501/1501, matrix(`mat')
  
  restore

end
